jaclearn.data.stat
==================

.. automodule:: jaclearn.data.stat

   
   
   

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      stat_histogram
   
   

   
   
   











.. rubric:: Functions

.. autofunction:: stat_histogram


